@@ -4,7 +4,13 @@ import jwt
 
 
 def decode_pastaporto(token: str, secret: str) -> dict[str, Any]:
-    return jwt.decode(token, str(secret), algorithms=["HS256"])
+    return jwt.decode(
+        token,
+        str(secret),
+        issuer="gateway",
+        algorithms=["HS256"],
+        options={"require": ["exp", "iss", "nbf", "iat"]},
+    )
 
 
 def decode_service_to_service_token(
@@ -17,5 +23,5 @@ def decode_service_to_service_token(
         audience=audience,
         issuer=issuer,
         algorithms=["HS256"],
-        options={"require": ["exp", "iss", "aud"]},
+        options={"require": ["exp", "iss", "aud", "nbf", "iat"]},
     )
